; Maybe this file should be made into a Guile module.  Maybe not.

; FIXME: do all of these really need to be here?

(define (launch-gnome fn)
  ; call to gtk-main moved to gnome-guile.c (federico)
  (fn)
  (gtk-main))

(define (gnome-internal-make-filled-box boxfunc homogeneous padding widgets)
  (let ((box (boxfunc homogeneous padding)))
    (for-each (lambda (widget)
		(if (not (null? widget))
		    (case (car (cddddr widget))
		      ((start) (gtk-box-pack-start box (car widget) (cadr widget) (caddr widget) (cadddr widget)))
		      ((end) (gtk-box-pack-end box (car widget) (cadr widget) (caddr widget) (cadddr widget))))
		    (gtk-widget-show (car widget))))
	      widgets)
    (gtk-widget-show box)
    box))

(define (gnome-make-filled-hbox homogeneous padding . widgets)
  (gnome-internal-make-filled-box gtk-hbox-new homogeneous padding widgets))

(define (gnome-make-filled-vbox homogeneous padding . widgets)
  (gnome-internal-make-filled-box gtk-vbox-new homogeneous padding widgets))

(define (gnome-boxed-widget widget expand fill padding where)
  (list widget expand fill padding where))
